==> dklibs-1.23.1.tbz: include/dkl2l.h <==
/*
Copyright (c) 2004-2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  its contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

/**	@file dkl2l.h convert ISO-LATIN-1 encoded characters to LaTeX sequence.

	This module provides functions to convert ISO-LATIN-1 encoded
	characters into the appropriate LaTeX sequence.
*/

#ifndef DK_L2L_INCLUDED
#define DK_L2L_INCLUDED 1

#include <dk.h>

#if defined(EXTERN)
#undef EXTERN
#endif
#ifndef DK_L2L_C
#if !DK_HAVE_PROTOTYPES
#define EXTERN extern
#else
#define EXTERN /* nix */
#endif
#else
#define EXTERN /* nix */
#endif

#if defined(__cplusplus)
extern "C" {
#endif



/**	Find LaTeX sequence for character \a c.
	@param	c	Character in the range 0x00-0xff.
	@return	String containing the LaTeX sequence to show the
	glyph for \a c. For some characters there is no LaTeX sequence
	(or at least no sequence known to me), a pointer to an
	empty string is returned for these characters.
*/
EXTERN char *
dk_l2l_encoding DK_PR((char c));



#if defined(__cplusplus)
}
#endif

#endif
/* DK_L2L_INCLUDED */

==> dklibs-1.26.0.tbz: include/dkl2l.h <==
/*
Copyright (c) 2004-2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

/**	@file dkl2l.h convert ISO-LATIN-1 encoded characters to LaTeX sequence.

	This module provides functions to convert ISO-LATIN-1 encoded
	characters into the appropriate LaTeX sequence.
*/

#ifndef DK_L2L_INCLUDED
#define DK_L2L_INCLUDED 1

#include <dk.h>

#if defined(EXTERN)
#undef EXTERN
#endif
#ifndef DK_L2L_C
#if !DK_HAVE_PROTOTYPES
#define EXTERN extern
#else
#define EXTERN /* nix */
#endif
#else
#define EXTERN /* nix */
#endif

#if defined(__cplusplus)
extern "C" {
#endif



/**	Find LaTeX sequence for character \a c.
	@param	c	Character in the range 0x00-0xff.
	@return	String containing the LaTeX sequence to show the
	glyph for \a c. For some characters there is no LaTeX sequence
	(or at least no sequence known to me), a pointer to an
	empty string is returned for these characters.
*/
EXTERN char *
dk_l2l_encoding DK_PR((char c));



#if defined(__cplusplus)
}
#endif

#endif
/* DK_L2L_INCLUDED */
